@@ -436,6 +436,10 @@ BOOST_PYTHON_MODULE (gfal2)
             &PyGfal2::GfaltParams::set_strict_copy,
             "If set to True, do only copy, and ignore checksum, parent creation, overwrite..."
         )
+        .add_property("transfer_cleanup", &PyGfal2::GfaltParams::get_transfer_cleanup,
+            &PyGfal2::GfaltParams::set_transfer_cleanup,
+            "Enable/disable the copy clean-up happening when a transfer fails (default enabled)"
+        )
         .add_property("proxy_delegation", &PyGfal2::GfaltParams::get_proxy_delegation,
             &PyGfal2::GfaltParams::set_proxy_delegation,
             "Enable or disable TPC with proxy delegation (default enabled)"
